@@ -14,12 +14,20 @@ from pynovice.score_card.data_woe import WeightOfEvidence
 import pandas as pd
 
 class FeatureGenerator:
-    def __init__(self):
+    def __init__(self,auto_fill_missing=True,missing=None):
         self.cate_coder_dict = {}
         self.binning_dict = {}
         self.woe_dict = {}
-        self.binning_woe_info = None
+        self.woe_defalut = {}
         self.fields = None #特征字段
+        if missing:
+            self.missing = missing
+            self.auto_fill_missing = False
+        else:
+            self.missing = -999
+            self.auto_fill_missing = auto_fill_missing
+        self.binning_woe_info = None
+        self.cate_fields_info = None
 
     def fit_transform(self, df_fields, df_label, category_fields=None, default_boxs=5, boxs_dict={},bins_dict={}):
         '''
@@ -32,6 +40,8 @@ class FeatureGenerator:
         :param bins_dict: 自定义分箱阈值，{field:[]}
         :return:
         '''
+        df_fields=df_fields.reset_index(drop=True)
+        df_label = df_label.reset_index(drop=True)
         if category_fields is None:
             category_fields = list()
 
@@ -65,10 +75,12 @@ class FeatureGenerator:
             woe = WeightOfEvidence()
             df_field = woe.fit_transform(df_field, df_label)
             self.woe_dict.update({field: woe})
+            self.woe_defalut.update({field:df_field.mode()[0]})## 众数
 
             df_fields.loc[:, field] = df_field
 
         self.binning_woe_info = self.get_binning_woe()
+        self.cate_fields_info = self.get_cate_info()
         return df_fields
 
     def transform(self,fields_json):
@@ -77,7 +89,10 @@ class FeatureGenerator:
             # 取数据
             field_value = fields_json.get(field_name)
             if not field_value:
-                feature.append(-999)
+                if self.auto_fill_missing:
+                    feature.append(self.woe_defalut.get(field_name))
+                else:
+                    feature.append(self.missing)
                 continue
             # 类别编码
             cate_coder = self.cate_coder_dict.get(field_name)
@@ -102,7 +117,9 @@ class FeatureGenerator:
         df_woe = pd.concat(field_woe,axis=0)
         return df_woe
 
-
+    def get_cate_info(self):
+        cate_fields_info = {field:cate.cate_dict for field,cate in self.cate_coder_dict.items()}
+        return cate_fields_info
 
 if __name__ == '__main__':
     import dill as pickle
@@ -112,8 +129,9 @@ if __name__ == '__main__':
     df.columns = ['field1', 'field2', 'label']
     df_fields, df_label = df[['field1', 'field2']], df['label']
 
-    feature_generator = FeatureGenerator()
-    feature_generator.fit_transform(df_fields,df_label,category_fields=['field1'])
+    feature_generator = FeatureGenerator(auto_fill_missing=True)
+    aa=feature_generator.fit_transform(df_fields,df_label,category_fields=['field1'])
+    print(feature_generator.cate_fields_info)
     print(feature_generator.binning_woe_info)
 
     # file_name = '../data/feature_generater.pkl'
@@ -121,7 +139,7 @@ if __name__ == '__main__':
     #
     # # load
     # feature_generator= pickle.load(open(file_name, "rb"))
-    fields_json = {'field1':4, 'field22':5, 'aa':9}
+    fields_json = {'field1':4, 'field232':5, 'aa':9}
     feature = feature_generator.transform(fields_json)
     print(feature)
 
